summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameproperty.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgameproperty.h')
-rw-r--r--libkdegames/kgame/kgameproperty.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/libkdegames/kgame/kgameproperty.h b/libkdegames/kgame/kgameproperty.h
index c6915606..04474603 100644
--- a/libkdegames/kgame/kgameproperty.h
+++ b/libkdegames/kgame/kgameproperty.h
@@ -21,7 +21,7 @@
#ifndef __KGAMEPROPERTY_H_
#define __KGAMEPROPERTY_H_
-#include <qdatastream.h>
+#include <tqdatastream.h>
#include <kdebug.h>
#include <typeinfo>
@@ -151,7 +151,7 @@ public:
/**
* Sets this property to emit a signal on value changed.
- * As the proerties do not inehrit QObject for optimisation
+ * As the proerties do not inehrit TQObject for optimisation
* this signal is emited via the KPlayer or KGame object
**/
void setEmittingSignal(bool p) { mFlags.bits.emitsignal=p; }
@@ -217,12 +217,12 @@ public:
* overwrite this method in order to use this class
* @param s The stream to read from
**/
- virtual void load(QDataStream& s) = 0;
+ virtual void load(TQDataStream& s) = 0;
/**
* Write the value into a stream. MUST be overwritten
**/
- virtual void save(QDataStream& s) = 0;
+ virtual void save(TQDataStream& s) = 0;
/**
* send a command to advanced properties like arrays
@@ -230,7 +230,7 @@ public:
* @param msgid The ID of the command - see PropertyCommandIds
* @param isSender whether this client is also the sender of the command
**/
- virtual void command(QDataStream &stream, int msgid, bool isSender=false);
+ virtual void command(TQDataStream &stream, int msgid, bool isSender=false);
/**
* @return The id of this property
@@ -261,25 +261,25 @@ public:
* @param name if not 0 you can assign a name to this property
*
**/
- int registerData(int id, KGamePropertyHandler* owner,PropertyPolicy p, QString name=0);
+ int registerData(int id, KGamePropertyHandler* owner,PropertyPolicy p, TQString name=0);
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
**/
- int registerData(int id, KGamePropertyHandler* owner, QString name=0);
+ int registerData(int id, KGamePropertyHandler* owner, TQString name=0);
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
**/
- int registerData(int id, KGame* owner, QString name=0);
+ int registerData(int id, KGame* owner, TQString name=0);
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
**/
- int registerData(int id, KPlayer* owner, QString name=0);
+ int registerData(int id, KPlayer* owner, TQString name=0);
/**
* This is an overloaded member function, provided for convenience.
@@ -287,7 +287,7 @@ public:
* In particular you can use this function to create properties which
* will have an automatic id assigned. The new id is returned.
**/
- int registerData(KGamePropertyHandler* owner,PropertyPolicy p=PolicyUndefined, QString name=0);
+ int registerData(KGamePropertyHandler* owner,PropertyPolicy p=PolicyUndefined, TQString name=0);
void unregisterData();
@@ -341,7 +341,7 @@ protected:
* @return TRUE if the message could be sent successfully, otherwise
* FALSE
**/
- bool sendProperty(const QByteArray& b);
+ bool sendProperty(const TQByteArray& b);
/**
* Causes the parent object to emit a signal on value change
@@ -420,7 +420,7 @@ private:
* queues the message. As soon as <em>all</em> messages in the message server
* which are before the changed property have been transferred the message
* server delivers the new value of the KGameProperty to all clients. A
- * QTimer::singleShot is used to queue the messages inside the
+ * TQTimer::singleShot is used to queue the messages inside the
* KMessageServer.
*
* This means that if you do the following:
@@ -433,7 +433,7 @@ private:
* then "value" will be "0". initData is used to initialize the property
* (e.g. when the KMessageServer is not yet running or can not yet be
* reached). This is because "myProperty = 10" or "myProperty.send(10)" send a
- * message to the KMessageServer which uses QTimer::singleShot to
+ * message to the KMessageServer which uses TQTimer::singleShot to
* queue the message. The game first has to go back into the event loop where
* the message is received. The KGamePropertyHandler receives the new value
* sets the property. So if you need the new value you need to store it in a
@@ -536,7 +536,7 @@ private:
* @section Custom classes:
*
* If you want to use a custum class with KGameProperty you have to implement the
* operators << and >> for QDataStream:
* \code
* class Card
* {
@@ -544,7 +544,7 @@ private:
* int type;
* int suite;
* };
- * QDataStream& operator<<(QDataStream& stream, Card& card)
+ * TQDataStream& operator<<(TQDataStream& stream, Card& card)
* {
* Q_INT16 type = card.type;
* Q_INT16 suite = card.suite;
@@ -552,7 +552,7 @@ private:
* s << suite;
* return s;
* }
- * QDataStream& operator>>(QDataStream& stream, Card& card)
+ * TQDataStream& operator>>(TQDataStream& stream, Card& card)
* {
* Q_INT16 type;
* Q_INT16 suite;
@@ -635,7 +635,7 @@ public:
* This function sends a new value over network.
*
* Note that the value DOES NOT change when you call this function. This
* function saves the value into a QDataStream and calls
* sendProperty where it gets forwarded to the owner and finally the
* value is sent over network. The KMessageServer now sends the
* value to ALL clients - even the one who called this function. As soon
@@ -675,8 +675,8 @@ public:
if (isLocked()) {
return false;
}
- QByteArray b;
- QDataStream stream(b, IO_WriteOnly);
+ TQByteArray b;
+ TQDataStream stream(b, IO_WriteOnly);
stream << v;
if (!sendProperty(b)) {
setLocal(v);
@@ -751,7 +751,7 @@ public:
* Saves the object to a stream.
* @param stream The stream to save to
**/
- virtual void save(QDataStream &stream)
+ virtual void save(TQDataStream &stream)
{
stream << mData;
}
@@ -777,7 +777,7 @@ public:
* Also calls emitSignal if isEmittingSignal is TRUE.
* @param s The stream to read from
**/
- virtual void load(QDataStream& s)
+ virtual void load(TQDataStream& s)
{
s >> mData;
setDirty(false);
@@ -842,7 +842,7 @@ private:
typedef KGameProperty<int> KGamePropertyInt;
typedef KGameProperty<unsigned int> KGamePropertyUInt;
-typedef KGameProperty<QString> KGamePropertyQString;
+typedef KGameProperty<TQString> KGamePropertyQString;
typedef KGameProperty<Q_INT8> KGamePropertyBool;
#endif
@@ -536,7 +536,7 @@ private:
*
* If you want to use a custum class with KGameProperty you have to implement the
- * operators << and >> for QDataStream:
+ * operators << and >> for TQDataStream:
* \code
* class Card
@@ -635,7 +635,7 @@ public:
*
* Note that the value DOES NOT change when you call this function. This
- * function saves the value into a QDataStream and calls
+ * function saves the value into a TQDataStream and calls
* sendProperty where it gets forwarded to the owner and finally the
* value is sent over network. The KMessageServer now sends the